@@ -90,8 +90,8 @@ EXTERN_C void xs_init(pTHX);
 EXTERN_C void boot_DynaLoader (pTHX_ CV* cv);
 
 /* plugin stuff */
-static guint             filtering_hook_id;
-static guint             manual_filtering_hook_id;
+static guint             filtering_hook_id = HOOK_NONE;
+static guint             manual_filtering_hook_id = HOOK_NONE;
 static MailFilteringData *mail_filtering_data  = NULL;
 static MsgInfo           *msginfo              = NULL;
 static gboolean          stop_filtering        = FALSE;
@@ -430,10 +430,11 @@ static void insert_attribute_hash(gchar *attr)
   if((tl = g_hash_table_lookup(attribute_hash,attr)) != NULL) {
     gpointer origkey;
     gpointer value;
-    g_hash_table_lookup_extended(attribute_hash,attr,&origkey,&value);
-    g_hash_table_remove(attribute_hash,origkey);
-    free_attribute_hash_key(origkey,value,NULL);
-    debug_print("Existing key `%s' freed.\n",attr);
+    if (g_hash_table_lookup_extended(attribute_hash,attr,&origkey,&value)) {
+	  g_hash_table_remove(attribute_hash,origkey);
+      free_attribute_hash_key(origkey,value,NULL);
+      debug_print("Existing key `%s' freed.\n",attr);
+    }
   }
 
   tl = g_new0(PerlPluginTimedSList,1);
@@ -1606,7 +1607,8 @@ static int perl_load_file(void)
     message = g_strdup_printf("Error processing Perl script file: "
             "(line numbers may not be valid)\n%s",
             SvPV(ERRSV,n_a));
-    val = alertpanel("Perl Plugin error",message,"Retry","Abort","Edit");
+    val = alertpanel("Perl Plugin error",message,"Retry","Abort","Edit",
+				ALERTFOCUS_FIRST);
     g_free(message);
 
     if(val == G_ALERTOTHER) {
@@ -2289,14 +2291,14 @@ gint plugin_init(gchar **error)
   filtering_hook_id = hooks_register_hook(MAIL_FILTERING_HOOKLIST,
             my_filtering_hook,
             GUINT_TO_POINTER(AUTO_FILTER));
-  if(filtering_hook_id == (guint) -1) {
+  if(filtering_hook_id == HOOK_NONE) {
     *error = g_strdup("Failed to register mail filtering hook");
     return -1;
   }
   manual_filtering_hook_id = hooks_register_hook(MAIL_MANUAL_FILTERING_HOOKLIST,
              my_filtering_hook,
              GUINT_TO_POINTER(MANU_FILTER));
-  if(manual_filtering_hook_id == (guint) -1) {
+  if(manual_filtering_hook_id == HOOK_NONE) {
     hooks_unregister_hook(MAIL_FILTERING_HOOKLIST, filtering_hook_id);
     *error = g_strdup("Failed to register manual mail filtering hook");
     return -1;
