@@ -529,8 +529,9 @@ static void get_rfc822_date_from_time_t(gchar *buf, gint len, time_t t)
 	struct tm buft2;
 
 	lt = localtime_r(&t, &buft2);
-	sscanf(asctime_r(lt, buft1), "%3s %3s %d %d:%d:%d %d\n",
-	       day, mon, &dd, &hh, &mm, &ss, &yyyy);
+	if (sscanf(asctime_r(lt, buft1), "%3s %3s %d %d:%d:%d %d\n",
+	       day, mon, &dd, &hh, &mm, &ss, &yyyy) != 7)
+		g_warning("failed reading date/time");
 	g_snprintf(buf, len, "%s, %d %s %d %02d:%02d:%02d %s",
 		   day, dd, mon, yyyy, hh, mm, ss, tzoffset(&t));
 #else
@@ -1451,10 +1452,11 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 	g_free(msgpath);
 
 	folder = folder_find_from_name ("vCalendar", vcal_folder_get_class());
-	if (folder)
+	if (folder) {
 		folder_item_scan(folder->inbox);
-
-	vcalviewer_reload(folder->inbox);
+		vcalviewer_reload(folder->inbox);
+	} else
+		g_warning("couldn't find vCalendar folder class");
 	return TRUE;
 }
 
