@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2018 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 #include "defs.h"
@@ -24,6 +23,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
+#include <math.h>
 
 #include "main.h"
 #include "utils.h"
@@ -183,7 +183,7 @@ static GNode *subject_hashtable_lookup(GHashTable *hashtable, MsgInfo *msginfo)
 
 		/* parent node must not be more then thread_by_subject_max_age
 		   days older then msginfo */
-		if (abs(difftime(msginfo->date_t, hashtable_msginfo->date_t)) >
+		if (fabs(difftime(msginfo->date_t, hashtable_msginfo->date_t)) >
                     prefs_common.thread_by_subject_max_age * 3600 * 24)
 			match = FALSE;
 
